package api;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;

public class FileUtil {

	private static final int BUFFER_SIZE = 8192;

	public static String readText(String filePath) {
		return readText(filePath, "UTF-8");
	}

	public static String readText(String filePath, String charset) {
		if (filePath == null) {
			throw new NullPointerException("filePath was null.");
		}

		InputStream is = null;
		try {
			is = new FileInputStream(new File(filePath));
			Reader reader = new InputStreamReader(is, charset);
			BufferedReader in = new BufferedReader(reader);
			StringBuilder out = new StringBuilder(128);
			char[] buf = new char[BUFFER_SIZE];
			int n;
			while ((n = in.read(buf)) >= 0) {
				out.append(buf, 0, n);
			}
			return out.toString();
		} catch (IOException e) {
			throw new RuntimeException(e);
		} finally {
			close(is);
		}
	}

	private static void close(InputStream is) {
		if (is == null) {
			return;
		}
		try {
			is.close();
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
	}
}
